@@ -23,8 +23,7 @@
 #' 'left', 'interactive' or a vector of two coordinates
 #' in map units (c(x, y)).
 #' @param pal a color palette name or a vector of colors
-#' @param alpha if \code{pal} is a \link{hcl.colors} palette name, the
-#' alpha-transparency level in the range \[0,1\]
+#' @param alpha opacity, in the range \[0,1\]
 #' @param inches size of the largest symbol (radius for circles, half width
 #' for squares) in inches
 #' @param border symbol border color(s)
@@ -65,16 +64,16 @@
 #' @export
 #' @details
 #' Some arguments are available for all types of legend: `val`, `pos`, `title`,
-#' `title_cex`, `val_cex`, `frame`, `bg`, `fg`, `size`, `adj`,
+#' `title_cex`, `val_cex`, `frame`, `bg`, `fg`, `size`, `adj`, `alpha`,
 #' `return_bbox` and `mar`).
 #'
 #'
 #' Relevant arguments for each specific legend types:
 #' * `leg(type = "prop", val, inches, symbol, col, lwd, border, val_rnd, self_adjust, horiz)`
-#' * `leg(type = "choro", val, pal, alpha, val_rnd, col_na, no_data, no_data_txt, box_border, horiz)`
-#' * `leg(type = "cont", val, pal, alpha, val_rnd, col_na, no_data, no_data_txt, box_border, horiz)`
-#' * `leg(type = "typo", val, pal, alpha, col_na, no_data, no_data_txt, box_border)`
-#' * `leg(type = "symb", val, pal, alpha, pch, cex, lwd, pch_na, cex_na, col_na, no_data, no_data_txt)`
+#' * `leg(type = "choro", val, pal, val_rnd, col_na, no_data, no_data_txt, box_border, horiz)`
+#' * `leg(type = "cont", val, pal, val_rnd, col_na, no_data, no_data_txt, box_border, horiz)`
+#' * `leg(type = "typo", val, pal, col_na, no_data, no_data_txt, box_border)`
+#' * `leg(type = "symb", val, pal, pch, cex, lwd, pch_na, cex_na, col_na, no_data, no_data_txt)`
 #' * `leg(type = "prop_line", val, col, lwd, val_rnd)`
 #' * `leg(type = "grad_line", val, col, lwd, val_rnd)`
 #'
@@ -256,7 +255,7 @@ leg <- function(type,
                 val,
                 pos = "left",
                 pal = "Inferno",
-                alpha = 1,
+                alpha = NULL,
                 col = "tomato4",
                 inches = .3,
                 symbol = "circle",
@@ -308,10 +307,22 @@ leg <- function(type,
   if (horiz) {
     h <- "_h"
   }
-  x <- do.call(
-    what = get(paste0("leg_", type, h)),
-    args = args,
-    envir = parent.frame()
-  )
+
+
+  ffun <- get(paste0("leg_", type, h))
+  pf <- parent.frame()
+
+
+  if(length(pos) == 1 && pos == "interactive"){
+    args$return_bbox <- TRUE
+    x <- do.call(what = ffun, args = args, envir = pf)
+    args$return_bbox <- return_bbox
+    args$pos <- c(x[[1]], x[[4]])
+  }
+
+  x <- grDevices::recordGraphics(
+    expr = do.call(what = ffun, args = args, envir = pf),
+    list = list(args = args, ffun = ffun, pf = pf),
+    env = getNamespace("maplegend"))
   return(invisible(x))
 }
