@@ -21,8 +21,7 @@
 #' vector of categories (for "symb" and "typo"),
 #' break labels (for "choro" and "grad_line").
 #' @param pal a color palette name or a vector of colors
-#' @param alpha if \code{pal} is a \link{hcl.colors} palette name, the
-#' alpha-transparency level in the range \[0,1\]
+#' @param alpha opacity, in the range \[0,1\]
 #' @param inches size of the largest symbol (radius for circles, half width
 #' for squares) in inches
 #' @param border symbol border color(s)
@@ -62,7 +61,7 @@ leg_comp <- function(leg,
                      type,
                      val,
                      pal = "Inferno",
-                     alpha = 1,
+                     alpha = NULL,
                      col = "tomato4",
                      inches = .3,
                      symbol = "circle",
