@@ -37,7 +37,7 @@
 leg_typo <- function(pos = "topright",
                      val,
                      pal = "Inferno",
-                     alpha = 1,
+                     alpha = NULL,
                      title = "Legend Title",
                      title_cex = .8 * size,
                      val_cex = .6 * size,
